# Table of Contents

- [obsolescence-risk-management](<./obsolescence-risk-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Obsolescence Risk Management](<./Obsolescence-Risk-Management.md>)
  - [Overview](<./Obsolescence-Risk-Management/Overview.md>)
  - [What is Obsolescence Risk Management?](<./Obsolescence-Risk-Management/What-is-Obsolescence-Risk-Management.md>)
  - [Why is Obsolescence Risk Management Relevant?](<./Obsolescence-Risk-Management/Why-is-Obsolescence-Risk-Management-Relevant.md>)
  - [Which SAP LeanIX Products are Needed for Obsolescence Risk Management?](<./Obsolescence-Risk-Management/Which-SAP-LeanIX-Products-are-Needed-for-Obsolescence-Risk-Management.md>)
  - [How to Manage Obsolescence Risk with SAP LeanIX](<./Obsolescence-Risk-Management/How-to-Manage-Obsolescence-Risk-with-SAP-LeanIX.md>)
  - [Step-by-Step Guide](<./Obsolescence-Risk-Management/Step-by-Step-Guide.md>)
  - [We'd love your feedback!](<./Obsolescence-Risk-Management/Wed-love-your-feedback.md>)
